==> v0.2.tar.gz: iwla/default_conf.py <==
# -*- coding: utf-8 -*-

import os

# Default configuration

# Default database directory
DB_ROOT = './output_db'
# Default HTML output directory
DISPLAY_ROOT = './output'

# Hooks directories (don't edit)
HOOKS_ROOT = 'plugins'
PRE_HOOK_DIRECTORY = HOOKS_ROOT + '.pre_analysis'
POST_HOOK_DIRECTORY = HOOKS_ROOT + '.post_analysis'
DISPLAY_HOOK_DIRECTORY = HOOKS_ROOT + '.display'
# Meta Database filename
META_PATH = os.path.join(DB_ROOT, 'meta.db')
# Database filename per month
DB_FILENAME = 'iwla.db'

# Web server log format (nginx style). Default is apache log format
log_format = '$server_name:$server_port $remote_addr - $remote_user [$time_local] ' +\
    '"$request" $status $body_bytes_sent ' +\
    '"$http_referer" "$http_user_agent"'

# Time format used in log format
time_format = '%d/%b/%Y:%H:%M:%S %z'

# Hooks that are loaded at runtime (only set names without path and extensions)
pre_analysis_hooks = []
post_analysis_hooks = []
display_hooks = []

# Extensions that are considered as a HTML page (or result) in opposite to hits
pages_extensions = ['/', 'htm', 'html', 'xhtml', 'py', 'pl', 'rb', 'php']
# HTTP codes that are cosidered OK
viewed_http_codes = [200, 304]

# If False, doesn't cout visitors that doesn't GET a page but resources only (images, rss...)
count_hit_only_visitors = True

# Multimedia extensions (not accounted as downloaded files)
multimedia_files = ['png', 'jpg', 'jpeg', 'gif', 'ico',
                    'css', 'js']

# Default resources path (will be symlinked in DISPLAY_OUTPUT)
resources_path = ['resources']
# Icon path
icon_path = '%s/%s' % (os.path.basename(resources_path[0]), 'icon')
# CSS path (you can add yours)
css_path = ['%s/%s/%s' % (os.path.basename(resources_path[0]), 'css', 'iwla.css')]

# Files extensions to compress in gzip during display build
compress_output_files = []

# Path to locales files
locales_path = './locales'

# Default locale (english)
locale = 'en_EN'

==> v0.4.tar.gz: iwla/default_conf.py <==
# -*- coding: utf-8 -*-

import os

# Default configuration

# Default database directory
DB_ROOT = './output_db'
# Default HTML output directory
DISPLAY_ROOT = './output'

# Hooks directories (don't edit)
HOOKS_ROOT = 'plugins'
PRE_HOOK_DIRECTORY = HOOKS_ROOT + '.pre_analysis'
POST_HOOK_DIRECTORY = HOOKS_ROOT + '.post_analysis'
DISPLAY_HOOK_DIRECTORY = HOOKS_ROOT + '.display'
# Meta Database filename
META_PATH = os.path.join(DB_ROOT, 'meta.db')
# Database filename per month
DB_FILENAME = 'iwla.db'

# Web server log format (nginx style). Default is apache log format
log_format = '$server_name:$server_port $remote_addr - $remote_user [$time_local] ' +\
    '"$request" $status $body_bytes_sent ' +\
    '"$http_referer" "$http_user_agent"'

# Time format used in log format
time_format = '%d/%b/%Y:%H:%M:%S %z'

# Hooks that are loaded at runtime (only set names without path and extensions)
pre_analysis_hooks = []
post_analysis_hooks = []
display_hooks = []

# Extensions that are considered as a HTML page (or result) in opposite to hits
pages_extensions = ['/', 'htm', 'html', 'xhtml', 'py', 'pl', 'rb', 'php']

# HTTP codes that are considered OK
viewed_http_codes = [200, 304]

# If False, doesn't cout visitors that doesn't GET a page but resources only (images, rss...)
count_hit_only_visitors = True

# Multimedia extensions (not accounted as downloaded files)
multimedia_files = ['png', 'jpg', 'jpeg', 'gif', 'ico', 'svg',
                    'css', 'js']

# Default resources path (will be symlinked in DISPLAY_OUTPUT)
resources_path = ['resources']
# Icon path
icon_path = '%s/%s' % (os.path.basename(resources_path[0]), 'icon')
# CSS path (you can add yours)
css_path = ['%s/%s/%s' % (os.path.basename(resources_path[0]), 'css', 'iwla.css')]

# Files extensions to compress in gzip during display build
compress_output_files = []

# Path to locales files
locales_path = './locales'

# Default locale (english)
locale = 'en_EN'
